rymndhng.logfmt

Creates logfmt-style logs from Clojure key-value pairs

For more context, see https://brandur.org/logfmt and https://brandur.org/canonical-log-lines

Creates logfmt-style logs from Clojure key-value pairs

For more context, see https://brandur.org/logfmt and https://brandur.org/canonical-log-lines
raw docstring

encodeclj

(encode m)

Encodes a sequence of entries as a logfmt string.

The sequence can come from map or a list of tuples

Encodes a sequence of entries as a logfmt string.

The sequence can come from map or a list of tuples
sourceraw docstring

encode-keyvalsclj

(encode-keyvals & keyvals)
source

logfmt-quoteclj

(logfmt-quote s)
source

cljdoc builds & hosts documentation for Clojure/Script libraries