Creates logfmt-style logs from Clojure key-value pairs
For more context, see https://brandur.org/logfmt and https://brandur.org/canonical-log-lines
Creates logfmt-style logs from Clojure key-value pairs For more context, see https://brandur.org/logfmt and https://brandur.org/canonical-log-lines
(encode m)Encodes a sequence of entries as a logfmt string.
The sequence can come from map or a list of tuples
Encodes a sequence of entries as a logfmt string. The sequence can come from map or a list of tuples
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |